# README #

This README would normally document whatever steps are necessary to get your application up and running.

### What is this repository for? ###

* Quick summary
* Version 0.1.0
* [Learn Markdown](https://bitbucket.org/tutorials/markdowndemo)

### How do I get set up? ###

* To set this up run the following command:
    ```shell
    pip install symbolic-quantum-computation
    ```
    Tu update:
    ```shell
    sudo pip install --upgrade symbolic-quantum-computation
    ```
    To run use:
    ```shell
    python3 sqc
    ```
* Configuration
* Dependencies
* Database configuration
* To run tests use:
    ```shell
    python3 sqc -t
    ```
* Deployment instructions

### Contribution guidelines ###

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* Repo owner or admin
* Other community or team contact